@@ -1,18 +1,12 @@
-"""
-CLI entry point for ai-rulez
-"""
-
 import subprocess
 import sys
 from .downloader import ensure_binary
 
 
 def main():
-    """Main entry point for the CLI."""
     binary_path = ensure_binary()
-    
+
     try:
-        
         result = subprocess.run([binary_path] + sys.argv[1:], check=False)
         sys.exit(result.returncode)
     except FileNotFoundError:
@@ -24,4 +18,4 @@ def main():
 
 
 if __name__ == "__main__":
-    main()
\ No newline at end of file
+    main()
